@@ -19,8 +19,8 @@ class Config(BaseConfig):
     default_fee_limit = 21000
 
 
-def process_config(config, arg, args, flags):
-    config = base_process_config(config, arg, args, flags)
+def process_config(config, arg, args, flags, positional_name=None):
+    config = base_process_config(config, arg, args, flags, positional_name=positional_name)
     if arg.match('provider', flags):
 
         if not bool(config.get('RPC_DIALECT')):
@@ -31,4 +31,8 @@ def process_config(config, arg, args, flags):
                 ]:
             raise ValueError('unknown rpc dialect {}'.format(config.get('RPC_DIALECT'))) 
 
+    if arg.match('create', flags):
+        config.add(getattr(args, 'null'), '_NULL')
+
+
     return config
